@@ -135,6 +135,14 @@ typedef int (wan_get_info_t)(char *, char **, off_t, int);
 #endif
  }           
 
+#if 1
+#define MOD_INC_USE_COUNT try_module_get(THIS_MODULE)
+#define MOD_DEC_USE_COUNT module_put(THIS_MODULE)
+#else
+#define MOD_INC_USE_COUNT 
+#define MOD_DEC_USE_COUNT
+#endif  
+
 #define ADMIN_CHECK()  {if (!capable(CAP_SYS_ADMIN)) {\
                              if (WAN_NET_RATELIMIT()) { \
                                  DEBUG_EVENT("%s:%d: wanpipe: ADMIN_CHECK: Failed !\n",__FUNCTION__,__LINE__);\
