@@ -64,7 +64,6 @@ static void tty_poll_task (struct work_struct *work)
 #endif      
 	struct tty_struct *tty;
 	netskb_t *skb;
-	char fp=0;
 	int err=0;
 	unsigned long smp_flags;
 
@@ -82,7 +81,7 @@ static void tty_poll_task (struct work_struct *work)
 #endif
 
 		if (ops->receive_buf)
-			ops->receive_buf(tty,wan_skb_data(skb),&fp,wan_skb_len(skb));
+			ops->receive_buf(tty,wan_skb_data(skb),NULL,wan_skb_len(skb));
 
 		wan_skb_free(skb);
 	}
