@@ -594,6 +594,7 @@ static int wp_tdmv_remora_hwec_create(struct dahdi_chan *chan, struct dahdi_echo
 	(*ec)->features = wp_tdmv_remora_ec_features;
 
 	wan_set_bit(chan->chanpos-1, &card->wandev.rtp_tap_call_map);
+	wp_fax_tone_timeout_set(wr,chan->chanpos-1);
 
 	if (card->wandev.ec_enable) {
 		/* The ec persist flag enables and disables
@@ -668,6 +669,7 @@ static int wp_remora_zap_hwec(struct zt_chan *chan, int enable)
 
 	if (enable) {
 		wan_set_bit(chan->chanpos-1,&card->wandev.rtp_tap_call_map);
+		wp_fax_tone_timeout_set(wr,chan->chanpos-1);
 	} else {
 		wan_clear_bit(chan->chanpos-1,&card->wandev.rtp_tap_call_map);
 	}
@@ -1643,8 +1645,6 @@ static int wp_tdmv_remora_is_rbsbits(wan_tdmv_t *wan_tdmv)
 }
 
 
-#ifdef WAN_FAKE_POLARITY
-#warning "WAN_FAKE_POLARITY Enabled - Experimental"
 static inline void wp_tdmv_dtmfcheck_fakepolarity(wp_tdmv_remora_t *wr, int channo, unsigned char *rxbuf)
 {
 	sdla_t		*card = wr->card;
@@ -1673,7 +1673,6 @@ static inline void wp_tdmv_dtmfcheck_fakepolarity(wp_tdmv_remora_t *wr, int chan
 		wr->mod[channo].fxo.readcid = 0;
 	}
 }
-#endif
 
 /******************************************************************************
 ** wp_tdmv_rx_chan() - 
@@ -1743,9 +1742,9 @@ DEBUG_EVENT("Module %d: RX: %02X %02X %02X %02X %02X %02X %02X %02X\n",
 	wr->chans[channo].readchunk = rxbuf;	
 	wr->chans[channo].writechunk = txbuf;	
 
-#ifdef WAN_FAKE_POLARITY
-	wp_tdmv_dtmfcheck_fakepolarity(wr,channo,rxbuf);
-#endif
+ 	if (card->fe.fe_cfg.cfg.remora.fake_polarity == WANOPT_YES){
+		wp_tdmv_dtmfcheck_fakepolarity(wr,channo,rxbuf);
+	}
 
 
 #ifdef CONFIG_PRODUCT_WANPIPE_TDM_VOICE_ECHOMASTER
